# pynatrace

Python CLI for Dynatrace
=======

### Description

pynatrace is a cli for the Dynatrace API
It is based on https://github.com/dynatrace-oss/api-client-python
Set the following environment variables
DT_API_KEY = 'API-YOURAPIKEY'
DT_SERVER_URI = 'https://activegate.example.com:9999/e/tenant_id'

### Install

```bash
$ pip install pynatrace
```

